package org.dromara.ems.record.mapper;

import org.dromara.ems.record.domain.EmsRecordWaterInstant;

import java.util.List;

/**
 * 水实时数据Mapper接口
 * 
 * @author Yinq
 * @date 2024-05-14
 */
public interface EmsRecordWaterInstantMapper 
{
    /**
     * 查询水实时数据
     * 
     * @param objId 水实时数据主键
     * @return 水实时数据
     */
    public EmsRecordWaterInstant selectEmsRecordWaterInstantByObjId(Long objId);

    /**
     * 查询水实时数据列表
     * 
     * @param emsRecordWaterInstant 水实时数据
     * @return 水实时数据集合
     */
    public List<EmsRecordWaterInstant> selectEmsRecordWaterInstantList(EmsRecordWaterInstant emsRecordWaterInstant);

    /**
     * 新增水实时数据
     * 
     * @param emsRecordWaterInstant 水实时数据
     * @return 结果
     */
    public int insertEmsRecordWaterInstant(EmsRecordWaterInstant emsRecordWaterInstant);

    /**
     * 修改水实时数据
     * 
     * @param emsRecordWaterInstant 水实时数据
     * @return 结果
     */
    public int updateEmsRecordWaterInstant(EmsRecordWaterInstant emsRecordWaterInstant);

    /**
     * 删除水实时数据
     * 
     * @param objId 水实时数据主键
     * @return 结果
     */
    public int deleteEmsRecordWaterInstantByObjId(Long objId);

    /**
     * 批量删除水实时数据
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsRecordWaterInstantByObjIds(Long[] objIds);
}
